#
# spec file for package adms
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
Name:           adms
Version:        2.3.7
Release:        2.3
Summary:        An automatic device model synthesizer
License:        GPL-3.0-only
Group:          Productivity/Scientific/Electronics
URL:            https://github.com/Qucs/ADMS
Source0:        https://github.com/Qucs/ADMS/archive/release-%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE adms-no-build-time.patch -- remove build time from binary
Patch1:         adms-no-build-time.patch
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  perl-XML-LibXML

%description
ADMS is a code generator that converts electrical compact device models
specified in high-level description language into ready-to-compile C code
for the API of SPICE simulators. Based on transformations specified in XML
language, ADMS transforms Verilog-AMS code into other target languages.

%package -n libadms%{sover}
Summary:        An automatic device model synthesizer
Group:          System/Libraries

%description -n libadms%{sover}
ADMS is a code generator that converts electrical compact device models
specified in high-level description language into ready-to-compile C code
for the API of SPICE simulators. Based on transformations specified in XML
language, ADMS transforms Verilog-AMS code into other target languages.

This package contains the libadms shared libraries.

%package devel
Summary:        C-Bindings development files for adms
Group:          Development/Languages/C and C++
Requires:       libadms%{sover} = %{version}

%description devel
This package contains all include files, libraries and configuration
files needed to develop programs that use adms.

%prep
%autosetup -p1 -n ADMS-release-%{version}

%build
./bootstrap.sh
%configure --enable-maintainer-mode --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libadms0 -p /sbin/ldconfig
%postun -n libadms0 -p /sbin/ldconfig

%files
%doc AUTHORS ChangeLog
%license COPYING
%{_bindir}/admsCheck
%{_bindir}/admsXml
%{_mandir}/man1/admsCheck.1%{?ext_man}
%{_mandir}/man1/admsXml.1%{?ext_man}

%files -n libadms%{sover}
%{_libdir}/libadmsAdmstpath.so.%{sover}*
%{_libdir}/libadmsElement.so.%{sover}*
%{_libdir}/libadmsPreprocessor.so.%{sover}*
%{_libdir}/libadmsVeriloga.so.%{sover}*

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/constants.vams
%{_includedir}/%{name}/disciplines.vams
%{_libdir}/libadmsAdmstpath.so
%{_libdir}/libadmsElement.so
%{_libdir}/libadmsPreprocessor.so
%{_libdir}/libadmsVeriloga.so

%changelog
* Mon Feb 26 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update URL to point to Github, Sourceforge repository is no
  longer active.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Tue Jan  5 2021 Matthias Eliasson <elimat@opensuse.org>
- update to version 2.3.7
  * reproducible build
  * typo fixes
  * include path
  * instructions
* Wed Aug  8 2018 jengelh@inai.de
- Expand shared library subpacakge description.
* Sat Jun 23 2018 antoine.belvire@opensuse.org
- Clean spec file.
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to version 2.3.6
  * Fix parser for parameter lists in subdevice instanciation.
  * Remove duplicated constants in provided headers.
  * Fix crash on x64 when printing message about standard headers.
- Moved to github
- Lint spec file
* Mon Apr 25 2016 p.drouand@gmail.com
- Update to version 2.3.5
  * Change license to GPLv3.
  * Add new simplified constants.vams and discplines.vams.
    Tested to work with models currently in use by Qucs, Ngspice, Xyce and Gnucap.
    Whenever these headers are used, adms informs the user about the
    availability of the standard headers at:
    http://accellera.org/downloads/standards/v-ams
  * Remove non-GPL constants.vams and disciplines.vams headers.
    These files are copyright of Accellera. With the LRM v2.4.0 updated versions
    of these files are freely accessible. However modification is not allowed.
    Hence, these files are not GPL and should not be included in adms.
  * Autotools, add back support for static and shared libraries build.
    Build shared libraries by default. Tested on Linux, Mac OSX, and MSYS2.
    See the configure --disable-shared flag to change that.
    CMake contiues to builds static libraries only.
  * Fix out-of-tree build for Autotools and CMake.
  * Check scaling factors againd LRM v2.4.0
    Add missing K scaling (uppercase kilo)
    standard scale_factor T|G|M|K|k|m|u|n|p|f|a
    Add testset (va and xml files) to test the scaling factors
  * Handle non-standard scaling factors with warning E|P|D|h|d|c|A
  * Relax Bison requirement, tested with (2.5, 3.0.2)
  * Perl GD module is no longer required at build time.
    The GD module is becoming hard to install, and it is only used to create
    a few images used on the html documentation. If images need to be changed,
    run the mkimage.pl script and update the repository.
- Change license to GPL-3.0, accordingly with upstream changes
- Remove perl-GD build dependency; not needed anymore
* Wed Oct  1 2014 dmitry_r@opensuse.org
- Update to version 2.3.4
  * bugfix release, see included ChangeLog file
- Update adms-no-build-time.patch
- Build without shared libraries.
* Thu Jul  3 2014 dmitry_r@opensuse.org
- Fix devel package requirements
* Fri Jun 27 2014 dmitry_r@opensuse.org
- Initial package, version 2.3.2
- Remove build time from binary
  * adms-no-build-time.patch
